@@ -8,7 +8,7 @@ function(hr1, hr2) {
 	beta2 <- hr2$coef
 	se1 <- hr1$se
 	se2 <- hr2$se
-	r <- cor(x1, x2, method="pearson", use="complete.obs")
+	r <- cor(x1, x2, method="spearman", use="complete.obs")
 	if(abs(r) < 1) {
 		t.stat <- (beta1 - beta2) / sqrt(se1^2 + se2^2 - 2 * r * se1 * se2)
 		diff.ci.p <- pt(q=t.stat, df=n - 1, lower.tail=FALSE)
