@@ -13,13 +13,21 @@ function(list.hr1, list.hr2, hetero=FALSE) {
 		x1.se <- c(x1.se, list.hr1[[i]]$se)
 		x2 <- c(x2, list.hr2[[i]]$coef)
 		x2.se <- c(x2.se, list.hr2[[i]]$se)
-		cort <- cor(list.hr1[[i]]$data$x, list.hr2[[i]]$data$x, method="pearson", use="complete.obs")
-		corz <- c(corz, fisherz(cort, inv=FALSE))
+		cort <- cor(list.hr1[[i]]$data$x, list.hr2[[i]]$data$x, method="spearman", use="complete.obs")
+		## since r is the spearman correlation coefficient and not the Pearson's one, we should apply a correction factor (see http://en.wikipedia.org/wiki/Spearman's_rank_correlation_coefficient for details)
+		corz <- c(corz, sqrt((nn - 3) / 1.06) * fisherz(cort, inv=FALSE))
 		if(nn > 3) { corz.se <- c(corz.se, 1 / sqrt(nn - 3)) } else { corz.se <- c(corz.se, NA) }
 	}
 	x1.meta <- combine.est(x=x1, x.se=x1.se, hetero=hetero, na.rm=TRUE)
 	x2.meta <- combine.est(x=x2, x.se=x2.se, hetero=hetero, na.rm=TRUE) 
-	r <- fisherz(combine.est(x=corz, x.se=corz.se, na.rm=TRUE, hetero=hetero)$estimate, inv=TRUE)
+	if(x1.meta$estimate == x2.meta$estimate && x1.meta$se == x2.meta$se) {
+	## same hazard ratios
+		return(list("p.value"=1, "cindex1"=x1.meta$estimate, "cindex2"=x2.meta$estimate))
+	}
+	rz <- combine.est(x=corz, x.se=corz.se, na.rm=TRUE, hetero=hetero)$estimate
+	## since r is the spearman correlation coefficient and not the Pearson's one, we should apply a correction factor (see http://en.wikipedia.org/wiki/Spearman's_rank_correlation_coefficient for details)
+	rz <- rz / (sqrt((n - 3) / 1.06))
+	r <- fisherz(rz, inv=TRUE)
 
 	if(abs(r) < 1) {
 		t.stat <- (x1.meta$estimate - x2.meta$estimate) / sqrt(x1.meta$se^2 + x2.meta$se^2 - 2 * r * x1.meta$se * x2.meta$se)
